#pragma once
#include <glm/glm.hpp>
#include <imgui.h>

inline void Inspector ()  {
    ImGui::Begin("Inspector");
    static float Zoom = 90;
    static glm::vec3 Position = glm::vec3(0.0f, 0.0f, 0.0f);
    static glm::vec3 Rotation = glm::vec3(0.0f, 0.0f, 0.0f);

    ImGui::BeginChild("Camera");

    ImGui::SliderFloat("Zoom", &Zoom, 10, 190);
    ImGui::InputFloat3("Position:", &Position[0]);

    ImGui::InputFloat3("Rotation:", &Rotation[0]);
    ImGui::EndChild();


    ImGui::BeginChild("Scripting");
    ImGui::Text("Hello world!");
    ImGui::EndChild();
    ImGui::End();
}

inline void SceneExplorer(Scene& scene) 
{

    ImGui::Begin("Scene Explorer");

    scene.getReg().each([&](auto entity) {
        auto id = scene.getReg().get<BarinkEngine::IdentifierComponent>(entity);
        ImGui::LabelText("##myObject", "%s", id.name.c_str());
        });


    ImGui::End();
}

inline void Viewport(Framebuffer& framebuffer , Scene& scene ) {

    unsigned int viewportWindowFlags = ImGuiWindowFlags_NoTitleBar 
        | ImGuiWindowFlags_NoDecoration 
        | ImGuiWindowFlags_NoScrollbar
        | ImGuiWindowFlags_NoMove
        | ImGuiWindowFlags_NoCollapse;

    ImGui::PushStyleVar(ImGuiStyleVar_WindowPadding, ImVec2{ 0,0 });
    ImGui::Begin("Viewport", false, viewportWindowFlags );
    ImGui::Image((void*)(intptr_t)framebuffer.GetColourAttachment(), ImVec2{ (float)800,(float)600 });

    ImGuizmo::SetDrawlist();
    ImGuizmo::SetRect(ImGui::GetWindowPos().x, ImGui::GetWindowPos().y, ImGui::GetWindowWidth(), ImGui::GetWindowHeight());
    ImGuizmo::Enable(true);
    auto cam = glm::mat4(1.0f);
    //ImGuizmo::Manipulate(glm::value_ptr(static_cam), glm::value_ptr(static_projection), ImGuizmo::TRANSLATE, ImGuizmo::WORLD, glm::value_ptr(trans));
    ImGuizmo::ViewManipulate(glm::value_ptr(cam), 8.0f, ImVec2{ 0.0f,0.0f }, ImVec2{ 128.0f,128.0f }, 0x10101010);
    ImGui::End();
    ImGui::PopStyleVar();

}

inline void Settings() {
    ImGui::Begin("Settings");
    ImGui::LabelText("##title-settings", "Fine grain control over your engine... ");
    ImGui::End();
}

inline void Console() {
    ImGui::Begin("Console", false );
    ImGui::Dummy(ImVec2{ 128, 128 });
    ImGui::End();
}

inline void AssetsFinder() {
    ImGui::Begin("Asset-Finder", false );
    ImGui::Dummy(ImVec2{ 128, 128 });
    ImGui::End();
}